netapp_ontap.models.performance_metric_io_type API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.performance_metric_io_type`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class PerformanceMetricIoTypeSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the PerformanceMetricIoType object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `other: Size GET POST PATCH`

    Performance metric for other I/O operations. Other I/O operations can be metadata operations, such as directory lookups and so on.

  `read: Size GET POST PATCH`

    Performance metric for read I/O operations.

    Example: 200

  `total: Size GET POST PATCH`

    Performance metric aggregated over all types of I/O operations.

    Example: 1000

  `write: Size GET POST PATCH`

    Performance metric for write I/O operations.

    Example: 100